import setuptools

setuptools.setup(
    name="trest_solar",
    version="1.0.1",
    author="LordMax2",
    description="Package to integrate Trest Solar in your Python project.",
    packages=["trest_solar"]
)